searchData={"content_type":"text/markdown","items":[{"doc":"`Telemetría` is the opinionated wrapper for [`:telemetry`](https://hexdocs.pm/telemetry)\nproviding handy macros to attach telemetry events to any function, private function,\nanonymous functions (on per-clause basis) and just random set of expressions.\n\n`Telemetría` exports three macros:\n\n- `deft/2` which is wrapping `Kernel.def/2`\n- `defpt/2` which is wrapping `Kernel.defp/2`\n- `t/2` which is wrapping the expression passed as the first parameter\n  and adds the options passed as a keyword to the second parameter to the\n  context of the respective telemetry event\n\n`Telemetría` allows compile-time telemetry events definition and provides\na compiler that is responsible for incremental builds and updates of the list of\nevents telemetry is aware about.","ref":"Telemetria.html","title":"Telemetria","type":"module"},{"doc":"Besides the functions listed above, one might attach `Telemetría` to the function\nby annotating it with `@telemetria` module attribute.\n\nThere are several options to pass to this attribute:\n\n- **`true`** — attach the `telemetry` to the function\n- **`if: boolean()`** — compile-time condition\n- **`if: (result -> boolean())`** — runtime condition\n- **`level: Logger,level()`** — specify a min logger level to attach telemetry\n- **`group: atom()`** — the configured group to manage event throttling,\n  see `:throttle` setting in `Telemetria.Options`\n- **`locals: [atom()]`** — the list of names of local variables to be exported\n  to the telemetry call","ref":"Telemetria.html#module-using-module-attribute","title":"Using module attribute - Telemetria","type":"module"},{"doc":"The following code would emit the telemetry event for the function `weather`,\n  returning `result` in Celcius _and_ injecting `farenheit` value under `locals`\n\n```elixir\ndefmodule Forecast do\n  use Telemetria\n\n  @telemetria level: :info, group: :weather_reports, locals: [:farenheit]\n  def weather(city) do\n    farenheit = ExternalService.retrieve(city)\n    Converter.farenheit_to_celcius(farenheit)\n  end\nend\n```","ref":"Telemetria.html#module-example","title":"Example - Telemetria","type":"module"},{"doc":"`Telemetría` takes care about managing events in the target application,\nmakes it a single-letter change to turn a function into a function wrapped\nwith telemetry call, measuring the execution time out of the box.\n\nIt also allows to easily convert expressions to be be telemetry-aware.\n\nBesides that, `telemetry: false` flag allows to purge the calls in compile-time\nresulting in zero overhead (useful for benchmark, or like.)","ref":"Telemetria.html#module-advantages","title":"Advantages - Telemetria","type":"module"},{"doc":"You need to include the compiler in `mix.exs`:\n\n```elixir\ndefmodule MyApp.MixProject do\n  def project do\n    [\n      # ...\n      compilers: [:telemetria | Mix.compilers()],\n      # ...\n    ]\n  end\n  # ...\nend\n```\n\nIn the modules you want to add telemetry to, you should `require Telemetria` (or,\npreferably, `import Telemetria` to make it available without FQN.) Once imported,\nthe macros are available and tracked by the compiler.\n\n```elixir\ndefmodule MyMod do\n  import Telemetria\n\n  defpt pi, do: 3.14\n  deft answer, do: 42 - pi()\n\n  def inner do\n    short_result = t(42 * 42)\n    result =\n      t do\n        # long calculations\n        :ok\n      end\n  end\nend\n```","ref":"Telemetria.html#module-example","title":"Example - Telemetria","type":"module"},{"doc":"`:telemetria` compiler keeps track of the events in the compiler manifest file\nto support incremental builds. Also it spits out `config/.telemetria.config.json`\nconfig for convenience. It might be used in in the release configuration as shown below.\n\n```elixir\nreleases: [\n  configured: [\n    # ...,\n    config_providers: [{Telemetria.ConfigProvider, \"/etc/telemetria.json\"}]\n  ]\n]\n```","ref":"Telemetria.html#module-use-in-releases","title":"Use in releases - Telemetria","type":"module"},{"doc":"* `:otp_app` (`t:atom/0`) - OTP application this telemetry is attached to. The default value is `:telemetria`.\n\n* `:enabled` (`t:boolean/0`) - Specifies whether telemetry should be enabled. The default value is `true`.\n\n* `:level` - Telemetria level to skip logging beyond, as in [Logger](https://hexdocs.pm/logger/Logger.html#module-application-configuration) The default value is `:debug`.\n\n* `:purge_level` - Telemetria level to purge beyond, as in [Logger](https://hexdocs.pm/logger/Logger.html#module-application-configuration) The default value is `:debug`.\n\n* `:throttle` - The throttling mechanism for throttling through too many events The default value is `:none`.\n\n* `:strict` (`t:boolean/0`) - Ignore `@telemetria` tags without `if` clause The default value is `false`.\n\n* `:smart_log` (`t:boolean/0`) - Log format to use; when true, custom json would be used The default value is `false`.\n\n* `:applications` (`t:keyword/0`) - List the applications to enable Telemetria support for, with parameters The default value is `[]`.\n\n* `:json_config_path` (`t:String.t/0`) - Relative path to JSON config The default value is `\"config/.telemetria.config.json\"`.\n\n* `:events` - The application-specific events.\n\n  See `t::telemetry.event_prefix/0` and `t::telemetry.event_name/0`.\n\n  The default value is `[]`.\n\n* `:handler` - Event handler for this application’s telemetry events. Arity must be 4. The default value is `{Telemetria.Handler.Default, :handle_event}`.\n\n* `:polling` (`t:keyword/0`) - The default value is `[enabled: false, flush: 5000, poll: 5000]`.\n\n  * `:enabled` (`t:boolean/0`) - Specifies whether polling should be enabled. The default value is `true`.\n\n  * `:flush` (`t:non_neg_integer/0`) - Flush interval. The default value is `5000`.\n\n  * `:poll` (`t:non_neg_integer/0`) - Poll interval. The default value is `5000`.\n\n* `:process_info` (`t:boolean/0`) - Specifies whether each telemetry event should include process info. The default value is `false`.","ref":"Telemetria.html#module-options","title":"Options - Telemetria","type":"module"},{"doc":"Declares a private function with a telemetry attached, measuring execution time","ref":"Telemetria.html#defpt/2","title":"Telemetria.defpt/2","type":"macro"},{"doc":"Declares a function with a telemetry attached, measuring execution time","ref":"Telemetria.html#deft/2","title":"Telemetria.deft/2","type":"macro"},{"doc":"Attaches telemetry to anonymous function (per clause,) or to expression(s)","ref":"Telemetria.html#t/2","title":"Telemetria.t/2","type":"macro"},{"doc":"","ref":"Telemetria.html#telemetry_prefix/2","title":"Telemetria.telemetry_prefix/2","type":"function"},{"doc":"JSON formatter that is aware of `Telemetria` metadata.\n\nThis code is gracefully stolen from internal Kantox Observability library.","ref":"Telemetria.Formatter.html","title":"Telemetria.Formatter","type":"module"},{"doc":"Formats a log entry.","ref":"Telemetria.Formatter.html#format/4","title":"Telemetria.Formatter.format/4","type":"function"},{"doc":"Default handler used unless the custom one is specified in config.\n\nThis handler collects `event`, `measurements`, `metadata`, and `config`,\npacks them into the keyword list and logs on `:info` log level.","ref":"Telemetria.Handler.Default.html","title":"Telemetria.Handler.Default","type":"module"},{"doc":"The protocol to be implemented for structs to decrease an amount of data\n  to be sent to `:telemetry` events.\n\n`Telemetria` reports the arguments in calls to wrapped functions as well as the result. \n  Sometimes it might be too noisy to grasp in logs. If `Telemetria.Inspect` protocol is\n  implemented for any kind of data to be spitted out, it would be applied instead of\n  `Inspect` to re-shape and possibly make the input value fingerprint less verbose.","ref":"Telemetria.Inspect.html","title":"Telemetria.Inspect","type":"protocol"},{"doc":"Converts `term` into an algebra document, to be used with `Telemetria` events.\n\n```elixir\niex|🌢|1 ▶ defmodule A, do: defstruct(foo: 42, bar: :baz)\niex|🌢|2 ▶ Telemetria.Inspect.inspect(%A{}, only: [:foo])\n‰A{foo: 42, …}\n```\n\nTo enable it for your struct, use `@derive Telemetria.Inspect` or\n  `@derive {Telemetria.Inspect, options}`.","ref":"Telemetria.Inspect.html#inspect/2","title":"Telemetria.Inspect.inspect/2","type":"function"},{"doc":"","ref":"Telemetria.Inspect.html#t:t/0","title":"Telemetria.Inspect.t/0","type":"type"},{"doc":"The behaviour to be implemented by consumers.\n\n`Telemetría` provides the default handler, that simply delegates to `Logger.info/1`.\n\n_See:_ `Telemetria.Handler.Default`.","ref":"Telemetria.Handler.html","title":"Telemetria.Handler","type":"behaviour"},{"doc":"The callback that will be invoked by `:telemetry`","ref":"Telemetria.Handler.html#c:handle_event/4","title":"Telemetria.Handler.handle_event/4","type":"callback"},{"doc":"Collects and formats the current process info to insert to metadata","ref":"Telemetria.Handler.html#process_info/1","title":"Telemetria.Handler.process_info/1","type":"function"},{"doc":"","ref":"Telemetria.Handler.html#t:process_info/0","title":"Telemetria.Handler.process_info/0","type":"type"},{"doc":"","ref":"Telemetria.Error.html","title":"Telemetria.Error","type":"exception"},{"doc":"# Telemetría    [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/am-kantox/telemetria/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/am-kantox/telemetria/workflows/Dialyzer/badge.svg)\n\n**The helper application that simplifies and standardizes telemetry usage.**","ref":"readme.html","title":"Telemetría","type":"extras"},{"doc":"```elixir\ndef project do\n  [\n    compilers: [:telemetria | Mix.compilers()]\n  ]\nend\n\ndef deps do\n  [\n    {:telemetria, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - Telemetría","type":"extras"},{"doc":"- **`0.18.0`** —\n  - [UPD] `locals: [:foo, :bar]` to export local vars from functions\n- **`0.17.0`** —\n  - [UPD] Configurable throttling groups\n- **`0.16.0`** —\n  - [UPD] Elixir v1.17\n- **`0.15.0`** —\n  - [UPD] Elixir v1.16\n- **`0.14.2`** —\n  - [ENH] `process_info: boolean()` option to embed the process info into each telemtry event \n- **`0.14.1`** —\n  - [ENH] Propagate `custom_options: [from: :telemetria]` down to inspect\n- **`0.14.0`** —\n  - [ENH] Allow `if: runtime_function` in `@telemetria` attribute in the form `&Mod.fun/1`,\n    which will receive the result _and_ emit the telemetry event if it returns `true`\n- **`0.13.0`** —\n  - [ENH] Allow `if: compile_time_boolean` in `@telemetria` attribute\n- **`0.12.0`** —\n  - [ENH] Allow `[transform: [args: M.f/1, result: {M, :f}]]` coercers in `@telemetria` attribute\n- **`0.11.1`** —\n  - [ENH] diagnostics improved\n- **`0.11.0`** —\n  - [FIX] properly handle `@telemetria` attribute on function heads and multiple clauses\n  - [ENH] purge level for telemetria hooks\n  - [ENH] level for telemetria logs\n- **`0.9.1`** —\n  - [ENH] `@telemetria process_info: true` keyword parameter\n  - [ENH] `@id` is set to the correct `otp_app`\n  - [ENH] `MFA` is set properly for alerts\n  - [ENH] arguments and result are grouped under `:call`\n  - [ENH] total metadata cleanup\n- **`0.9.0`** —\n  - [ENH] add `Telemetria.Formatter` that can be used to produce JSON logs basing on metadata, natively integrated into `telemetría`\n- **`0.8.0`** —\n  - [ENH] add `applications` option accepting a keyword list of applications to enable `telemetria` for (with optional parameters)\n- **`0.7.0`** —\n  - [ENH] add named arguments in all calls to event’s context\n- **`0.6.1`** —\n  - [BUG] wrong order using telemetry with many clauses\n- **`0.6.0`** —\n  - [ENH] accept parameters in annotation `@telemetria`\n  - [MIN] better print of events added\n- **`0.5.2`** —\n  - [ENH] `enabled: false` config to purge all telemetria code at once\n- **`0.5.1`** —\n  - [ENH] add result of underlying call to metric\n  - [ENH] decrease an amount of garbage returned from caller context\n- **`0.5.0`** —\n  - [ENH] annotation `@telemetria true` as a synonym to `deft/2`\n  - [FIX] polling is off by default\n- **`0.4.0`** —\n  - [ENH] default polling of system / vm states for free\n  - [ENH] starting in phases ensuring proper instrumenter setup\n- **`0.3.0`** —\n  - [ENH] no need for any config in any environment\n  - [BUG] proper handling of guards in compiler, correct event names\n\n## [Documentation](https://hexdocs.pm/telemetria).","ref":"readme.html#changelog","title":"Changelog - Telemetría","type":"extras"},{"doc":"# Optional Telemetria Support\n\nTo optionally include `telemetria` support to your library do the following.\n\n## `mix.exs`\n\nIn your `mix.exs` file, specify the dependency as `optional: true`\n\n```elixir\ndefp deps do\n  ...\n  {:telemetria, \"~> 0.4\", optional: true}\n  ...\nend\n```","ref":"optional-using.html","title":"Optional Telemetria Support","type":"extras"},{"doc":"Declare the custom module `MyApp.Telemetria` as shown below.\n\n```elixir\ndefmodule MyApp.Telemetria do\n  @moduledoc false\n\n  @default_options [use: [], apply: [level: :info]]\n\n  @all_options :telemetria\n               |> Application.get_env(:applications, [])\n               |> Keyword.get(:my_app, [])\n  @options if @all_options == true,\n             do: @default_options,\n             else: Keyword.merge(@default_options, @all_options)\n\n  @use @options != [] and match?({:module, Telemetria}, Code.ensure_compiled(Telemetria))\n\n  defmacro __using__(opts \\\\ []),\n    do: if(@use, do: quote(do: use(Telemetria, unquote(opts))), else: :ok)\n\n  @spec use? :: boolean()\n  def use?, do: @use\n\n  @spec use!(module :: module(), opts :: keyword()) :: :ok | nil\n  def use!(module, opts \\\\ true),\n    do: if(Rambla.Telemetria.use?(), do: Module.put_attribute(module, :telemetria, opts))\nend\n```","ref":"optional-using.html#custom-module","title":"Custom Module - Optional Telemetria Support","type":"extras"},{"doc":"In the module(s) where you want to optinally use `Telemetria`, add\n`use MyApp.Telemetria`. All the attributes are to be now declared with\n\n```elixir\nif Rambla.Telemetria.use?(), do: @telemetria(level: :info)\n```\n\nor\n\n```elixir\nRambla.Telemetria.use!(__MODULE__, level: :info)\n```\n\nThat’s it. Enjoy.","ref":"optional-using.html#conditional-include","title":"Conditional Include - Optional Telemetria Support","type":"extras"}],"producer":{"name":"ex_doc","version":"0.35.1"},"proglang":"elixir"}